//
//  PhoneViewController.m
//  PhoneAppSkin
//
//  Created by Mark Hammonds on 2/17/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "PhoneViewController.h"


@implementation PhoneViewController

@synthesize phoneNumberString;
@synthesize phoneNumberLabel;

-(id)initWithCoder:(NSCoder *)aDecoder
{
    self = [super initWithCoder:aDecoder];
    if(self)
    {
        phoneNumberString = [[NSString alloc] init];
        
        for(int count = 0; count < 10; count++){
            NSString *toneFilename = [NSString stringWithFormat:@"DTMF_%02d", count];
            
            NSURL *toneURLRef = [[NSBundle mainBundle] URLForResource:toneFilename
                                                        withExtension:@"wav"];
            SystemSoundID toneSSID = 0;
            
            AudioServicesCreateSystemSoundID(
                                             (CFURLRef) toneURLRef,
                                             &toneSSID
                                             );
            toneSSIDs[count] = toneSSID;
        }
    }
    
    return self;
}
- (void)viewDidUnload {
    [self setPhoneNumberLabel:nil];
    [super viewDidUnload];
}

- (void)dealloc {
    [phoneNumberString release];
    [phoneNumberLabel release];
    [super dealloc];
}

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
}

- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc. that aren't in use.
}

-(void)displayPhoneNumber
{
    if([self.phoneNumberString length] >= 4 && [self.phoneNumberString length] <= 7)
    {
        NSRange  prefixRange   = {0, 3};
        NSString *prefixString = [self.phoneNumberString substringWithRange:prefixRange];
        
        NSString *lineNumberString = [self.phoneNumberString substringFromIndex:3];
        
        self.phoneNumberLabel.text = [NSString stringWithFormat:@"%@-%@", prefixString, lineNumberString];
    }
    else if([self.phoneNumberString length] >= 8 && [self.phoneNumberString length] <= 10)
    {
        NSRange areaCodeRange = {0, 3};
        NSString *areaCodeString = [self.phoneNumberString substringWithRange:areaCodeRange];
        
        NSRange prefixRange = {3, 3};
        NSString *prefixString = [self.phoneNumberString substringWithRange:prefixRange];
        
        NSString *lineNumberString = [self.phoneNumberString substringFromIndex:6];
        
        self.phoneNumberLabel.text = [NSString stringWithFormat:@"(%@) %@-%@", areaCodeString, prefixString, lineNumberString];
        
    }    
    else
    {
        self.phoneNumberLabel.text = self.phoneNumberString;
    }    
}

-(IBAction)numberButtonPressed:(UIButton *)pressedButton
{
    int toneIndex = [pressedButton.titleLabel.text intValue];
    SystemSoundID toneSSID = toneSSIDs[toneIndex];
    AudioServicesPlaySystemSound(toneSSID);
    
    self.phoneNumberString = [self.phoneNumberString stringByAppendingString:pressedButton.titleLabel.text];
    [self displayPhoneNumber];
}

-(IBAction)deleteButtonPressed:(UIButton *)numberButton
{
    if([self.phoneNumberString length] > 0)
    {
        self.phoneNumberString = [self.phoneNumberString substringToIndex:([self.phoneNumberString length] - 1)];
    }
    
    [self displayPhoneNumber];
}

-(IBAction)dialButtonPressed:(UIButton *)numberButton
{
    NSString *phoneLinkString = [NSString stringWithFormat:@"tel:%@", self.phoneNumberString];
    NSURL *phoneLinkURL = [NSURL URLWithString:phoneLinkString];
    [[UIApplication sharedApplication] openURL:phoneLinkURL];
}


@end
